@@ -12,7 +12,7 @@ use async_tungstenite::{
 
 use futures::SinkExt;
 use futures::StreamExt;
-use std::borrow::Borrow;
+use std::borrow::{Borrow, Cow};
 
 use std::net::SocketAddr;
 use std::sync::Arc;
@@ -30,6 +30,7 @@ pub use async_trait::async_trait;
 
 use async_tungstenite::tungstenite::http::{Response, StatusCode};
 pub use async_tungstenite::tungstenite::protocol::{frame::coding::CloseCode, CloseFrame};
+use async_tungstenite::tungstenite::Message;
 
 /// Our WebSocket Session Collection
 pub type WebSocketSessions = Arc<RwLock<HashMap<Uuid, WebSocketSession>>>;
@@ -65,7 +66,9 @@ impl Server {
         tokio::spawn(async move {
             while let Some(result) = rx.recv().await {
                 tracing::trace!("Sending message to websocket connection: {:?}", result);
-                ws_session_tx.send(result).await.unwrap();
+                if let Err(e) = ws_session_tx.send(result).await {
+                    tracing::error!("Unable to send message to websocket: {:?}", e);
+                }
             }
         });
 
@@ -87,6 +90,13 @@ impl Server {
                         };
                     }
                     Err(e) => {
+                        let _ = server_tx2.send((
+                            session_id,
+                            Message::Close(Some(CloseFrame {
+                                code: CloseCode::Abnormal,
+                                reason: Cow::Owned(format!("ws_session_rx.next() error: {:?}", e)),
+                            })),
+                        ));
                         tracing::error!("ws_session_rx.next() error: {}", e);
                         return;
                     }
